/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2 of the GNU General Public License ("GPLv2 License")
 * or BSD License.
 *
 * GPLv2 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See http://www.gnu.org/licenses/gpl-2.0.html for more details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/
/*----------------------------------------------------------------------------*/
/*! @file u_hbbtv_drm.h
 *  $RCSfile: $
 *  $Revision: #1 $
 *  $Date: 2015/11/26 $
 *  $Author: dtvbm11 $
 *
 *  @par Description:This header file contains HBBTV streaming exported constants, macros, and types.
 */
/*----------------------------------------------------------------------------*/
#ifndef _U_HBBTV_DRM_H_
#define _U_HBBTV_DRM_H_

#include <features.h>

__BEGIN_DECLS

#include "u_common.h"
#include "mtkdrm.h"

#define HBBTV_DRM_LICENSE_URL_LEN   			  (1024)
#define HBBTV_DRM_PLAYREADY_KEY_NUM   			  (16)
#define HBBTV_DRM_PLAYREADY_DECRYPT_CONTEXT_NUM   (16)

#define HBBTV_DRM_OIPF_ID_PREFIX    "urn:dvb:casystemid:"
#define HBBTV_DRM_OIPF_ID_PLAYREADY (HBBTV_DRM_OIPF_ID_PREFIX "19219")
#define HBBTV_DRM_OIPF_ID_MARLIN    (HBBTV_DRM_OIPF_ID_PREFIX "19188")

typedef void (*pf_drm_msg_nfy)( MTKDRM_RESULT_E code,
                                 const char *result_msg,
                                 void *ref );



typedef struct _HBBTV_DRM_PLAYREADY_ENCRYPINFO_T
{
     MTKDRM_INITIATOR_TYPE   e_initiator_type;
     PLAYREADY_ENCRYPT_INFO  t_playready_key[HBBTV_DRM_PLAYREADY_KEY_NUM];
     PLAYREADY_DECRYPT_INFO  t_playready_decrypt_context[HBBTV_DRM_PLAYREADY_DECRYPT_CONTEXT_NUM];
     CHAR                    aui1_CID[HBBTV_DRM_PLAYREADY_KEY_NUM][MTKDRM_MARLIN_CONTENT_ID_LENGTH];
     UINT8                   ui1_key_num;


}PLAYREADY_ENCRYPINFO_T;

typedef struct _HBBTV_DRM_CIPLUS_ENCRYPINFO_T
{
     UINT16					ui2_casystemid;
}CIPLUS_ENCRYPINFO_T;

typedef struct _HBBTV_DRM_ENCRYPINFO_T
{
    MTKDRM_TYPE_E           t_drm_type;
    MTKDRM_HANDLE_T         t_drm_handle;

    union
    {
       PLAYREADY_ENCRYPINFO_T  t_playready_encrypinfo;
	   CIPLUS_ENCRYPINFO_T				t_ciplus_encrypinfo;
    }u_data;

}  HBBTV_DRM_ENCRYPINFO_T;

typedef enum
{
    HBBTV_DRM_RIGHTS_ISSUER_URL,
    HBBTV_DRM_SLIENT_RIGHTS_URL,
    HBBTV_DRM_CONTENT_ID,
    HBBTV_DRM_PREVIEW_RIGHTS_URL,
    HBBTV_DRM_PRIVATE_DATA,
    HBBTV_DRM_DONOT_RECORD,
    HBBTV_DRM_DONOT_TIMESHIFT,
    HBBTV_DRM_CONTROL_INFO_TYPE_NUM
} HBBTV_DRM_CONTROL_INFO_TYPE_E;

typedef struct _HBBTV_DRM_CONTROL_INFO_T
{
    HBBTV_DRM_CONTROL_INFO_TYPE_E     e_control_info_type;
    VOID                              *pv_data;
    UINT32                            ui4_data_len;
}  HBBTV_DRM_CONTROL_INFO_T;
/*------------------------------------------------------------------*/
/*! @enum HBBTV_DRM_CI_NFY_COND_T
 *  @li@c  HBBTV_DRM_CIPLUS_NFY_COND_CARD_INSERT                           -notify that the Card is insterted,
 *                                                                                     pv_data in x_ci_nfy_fct is NULL
 *  @li@c  HBBTV_DRM_CIPLUS_NFY_COND_CARD_REMOVE                           -notify that the Card is removed
 *                                                                                     pv_data in x_ci_nfy_fct is NULL
 *  @li@c  HBBTV_DRM_CIPLUS_NFY_COND_PARENTAL_CONTROL_INFO   -notify cam sent parental control info
 *                                                                                     pv_data in x_ci_nfy_fct is HBBTV_DRM_CIPLUS_PARENTAL_CONTROL_INFO* value
*  @li@c  HBBTV_DRM_CIPLUS_NFY_COND_SYSTEM_INFO   -notify cam sent system info
*												    pv_data in x_ci_nfy_fct is HBBTV_DRM_CIPLUS_SYSTEM_INFO* value
*  @li@c  HBBTV_DRM_CIPLUS_NFY_COND_RIGHTS_INFO   -notify cam sent rights info
*												    pv_data in x_ci_nfy_fct is HBBTV_DRM_CIPLUS_RIGHTS_INFO* value
*/

typedef enum
{
    HBBTV_DRM_CIPLUS_NFY_COND_CARD_INSERT = 0,
    HBBTV_DRM_CIPLUS_NFY_COND_CARD_REMOVE,
    HBBTV_DRM_CIPLUS_NFY_COND_PARENTAL_CONTROL_INFO,
    HBBTV_DRM_CIPLUS_NFY_COND_SYSTEM_INFO,
    HBBTV_DRM_CIPLUS_NFY_COND_RIGHTS_INFO
}HBBTV_DRM_CIPLUS_NFY_COND_T;

typedef struct
{
   uint8_t access_status;
   uint8_t rating_type;
   uint8_t rating_value;
   uint8_t *country_codes;
   uint16_t country_codes_len;
   uint8_t *parental_control_url;
   uint16_t url_len;
} HBBTV_DRM_CIPLUS_PARENTAL_CONTROL_INFO;

typedef struct
{
   uint16_t ca_system_id;
   uint8_t  access_status;
   uint8_t *rights_issuer_url;
   uint16_t url_len;
} HBBTV_DRM_CIPLUS_RIGHTS_INFO;

typedef struct
{
   uint16_t ca_system_id;
   uint8_t *ca_info;
   uint16_t ca_info_len;
} HBBTV_DRM_CIPLUS_SYSTEM_INFO;

typedef void (*hbbtv_drm_ciplus_nfy_fct)(
    HBBTV_DRM_CIPLUS_NFY_COND_T   e_nfy_cond,
    void*               pv_data,
    void*				pv_tag);

__END_DECLS

#endif /* _U_HBBTV_DRM_H_ */
